/*
 * Code for class ET_ASSERTION
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "et552.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {ET_ASSERTION}.reset */
void F1451_13530 (EIF_REFERENCE Current)
{
	GTCX
	
	
	RTGC;
}

/* {ET_ASSERTION}.is_class_assertion */
EIF_BOOLEAN F1451_13531 (EIF_REFERENCE Current)
{
	GTCX
	
	
	RTGC;
	return (EIF_BOOLEAN) 0;
}

/* {ET_ASSERTION}.assertion */
EIF_REFERENCE F1451_13533 (EIF_REFERENCE Current)
{
	GTCX
	
	
	return (EIF_REFERENCE) Current;
}

void EIF_Minit552 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
